@@ -23,7 +23,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.3.3';
+our $VERSION = '3.3.4';
 
 =head1 SYNOPSIS
 
@@ -41,7 +41,7 @@ my %valid_options = (
     # Main options
     v               => {valid => q[],                                                    default => 3},
     page            => {valid => [qr/^(?!0+\z)\d+\z/],                                   default => 1},
-    http_proxy      => {valid => [qr{^https?://}],                                       default => undef},
+    http_proxy      => {valid => [qr{.}],                                                default => undef},
     hl              => {valid => [qr/^\w+(?:[\-_]\w+)?\z/],                              default => undef},
     maxResults      => {valid => [1 .. 50],                                              default => 10},
     topicId         => {valid => [qr/^./],                                               default => undef},
@@ -279,13 +279,13 @@ sub set_lwp_useragent {
     $agent->ssl_opts(Timeout => 30);
     $agent->default_header('Accept-Encoding' => $accepted_encodings);
     $agent->conn_cache($cache);
-    $agent->proxy('http', $self->get_http_proxy) if (defined($self->get_http_proxy));
+    $agent->proxy(['http', 'https'], $self->get_http_proxy) if defined($self->get_http_proxy);
 
-    my $http_proxy = $agent->proxy('http');
-    if (defined($http_proxy)) {
-        $agent->proxy('https', $http_proxy) if (!defined($agent->proxy('https')));
-        $agent->timeout(30);
-    }
+    #my $http_proxy = $agent->proxy('http');
+    #if (defined($http_proxy)) {
+    #    $agent->proxy('https', $http_proxy) if (!defined($agent->proxy('https')));
+    #    $agent->timeout(30);
+    #}
 
     push @{$self->{lwp}->requests_redirectable}, 'POST';
     return $self->{lwp};
@@ -758,6 +758,9 @@ sub post_as_json {
             local $ENV{http_proxy}  = $self->{lwp}->proxy('http');
             local $ENV{https_proxy} = $self->{lwp}->proxy('https');
 
+            local $ENV{HTTP_PROXY}  = $self->{lwp}->proxy('http');
+            local $ENV{HTTPS_PROXY} = $self->{lwp}->proxy('https');
+
                 $name eq 'exec'   ? exec(@args)
               : $name eq 'system' ? system(@args)
               : $name eq 'stdout' ? qx(@args)
